==> hmd-0.4.9.crate: hmd-0.4.9/math.md <==

# Math Formula

[[toc]]

## Symbols

### lt

`[[math]]lt[[/math]]`: [[math]]lt[[/math]]

### gt

`[[math]]gt[[/math]]`: [[math]]gt[[/math]]

### leq

`[[math]]leq[[/math]]`: [[math]]leq[[/math]]

### geq

`[[math]]geq[[/math]]`: [[math]]geq[[/math]]

### ll

`[[math]]ll[[/math]]`: [[math]]ll[[/math]]

### gg

`[[math]]gg[[/math]]`: [[math]]gg[[/math]]

### equiv

`[[math]]equiv[[/math]]`: [[math]]equiv[[/math]]

### subset

`[[math]]subset[[/math]]`: [[math]]subset[[/math]]

### supset

`[[math]]supset[[/math]]`: [[math]]supset[[/math]]

### approx

`[[math]]approx[[/math]]`: [[math]]approx[[/math]]

### in

`[[math]]in[[/math]]`: [[math]]in[[/math]]

### ni

`[[math]]ni[[/math]]`: [[math]]ni[[/math]]

### subseteq

`[[math]]subseteq[[/math]]`: [[math]]subseteq[[/math]]

### supseteq

`[[math]]supseteq[[/math]]`: [[math]]supseteq[[/math]]

### cong

`[[math]]cong[[/math]]`: [[math]]cong[[/math]]

### simeq

`[[math]]simeq[[/math]]`: [[math]]simeq[[/math]]

### notin

`[[math]]notin[[/math]]`: [[math]]notin[[/math]]

### propto

`[[math]]propto[[/math]]`: [[math]]propto[[/math]]

### neq

`[[math]]neq[[/math]]`: [[math]]neq[[/math]]

### therefore

`[[math]]therefore[[/math]]`: [[math]]therefore[[/math]]

### because

`[[math]]because[[/math]]`: [[math]]because[[/math]]

### pm

`[[math]]pm[[/math]]`: [[math]]pm[[/math]]

### mp

`[[math]]mp[[/math]]`: [[math]]mp[[/math]]

### times

`[[math]]times[[/math]]`: [[math]]times[[/math]]

### div

`[[math]]div[[/math]]`: [[math]]div[[/math]]

### star

`[[math]]star[[/math]]`: [[math]]star[[/math]]

### cap

`[[math]]cap[[/math]]`: [[math]]cap[[/math]]

### cup

`[[math]]cup[[/math]]`: [[math]]cup[[/math]]

### vee

`[[math]]vee[[/math]]`: [[math]]vee[[/math]]

### wedge

`[[math]]wedge[[/math]]`: [[math]]wedge[[/math]]

### cdot

`[[math]]cdot[[/math]]`: [[math]]cdot[[/math]]

### diamond

`[[math]]diamond[[/math]]`: [[math]]diamond[[/math]]

### bullet

`[[math]]bullet[[/math]]`: [[math]]bullet[[/math]]

### oplus

`[[math]]oplus[[/math]]`: [[math]]oplus[[/math]]

### ominus

`[[math]]ominus[[/math]]`: [[math]]ominus[[/math]]

### otimes

`[[math]]otimes[[/math]]`: [[math]]otimes[[/math]]

### oslash

`[[math]]oslash[[/math]]`: [[math]]oslash[[/math]]

### odot

`[[math]]odot[[/math]]`: [[math]]odot[[/math]]

### circ

`[[math]]circ[[/math]]`: [[math]]circ[[/math]]

### exists

`[[math]]exists[[/math]]`: [[math]]exists[[/math]]

### nexists

`[[math]]nexists[[/math]]`: [[math]]nexists[[/math]]

### forall

`[[math]]forall[[/math]]`: [[math]]forall[[/math]]

### neg

`[[math]]neg[[/math]]`: [[math]]neg[[/math]]

### land

`[[math]]land[[/math]]`: [[math]]land[[/math]]

### lor

`[[math]]lor[[/math]]`: [[math]]lor[[/math]]

### rightarrow

`[[math]]rightarrow[[/math]]`: [[math]]rightarrow[[/math]]

### leftarrow

`[[math]]leftarrow[[/math]]`: [[math]]leftarrow[[/math]]

### iff

`[[math]]iff[[/math]]`: [[math]]iff[[/math]]

### top

`[[math]]top[[/math]]`: [[math]]top[[/math]]

### bot

`[[math]]bot[[/math]]`: [[math]]bot[[/math]]

### varnothing

`[[math]]varnothing[[/math]]`: [[math]]varnothing[[/math]]

### quad

`[[math]]quad[[/math]]`: [[math]]quad[[/math]]

### backslash

`[[math]]backslash[[/math]]`: [[math]]backslash[[/math]]

### leftcurlybrace

`[[math]]leftcurlybrace[[/math]]`: [[math]]leftcurlybrace[[/math]]

### rightcurlybrace

`[[math]]rightcurlybrace[[/math]]`: [[math]]rightcurlybrace[[/math]]

### alpha

`[[math]]alpha[[/math]]`: [[math]]alpha[[/math]]

### beta

`[[math]]beta[[/math]]`: [[math]]beta[[/math]]

### gamma

`[[math]]gamma[[/math]]`: [[math]]gamma[[/math]]

### Gamma

`[[math]]Gamma[[/math]]`: [[math]]Gamma[[/math]]

### delta

`[[math]]delta[[/math]]`: [[math]]delta[[/math]]

### Delta

`[[math]]Delta[[/math]]`: [[math]]Delta[[/math]]

### epsilon

`[[math]]epsilon[[/math]]`: [[math]]epsilon[[/math]]

### zeta

`[[math]]zeta[[/math]]`: [[math]]zeta[[/math]]

### eta

`[[math]]eta[[/math]]`: [[math]]eta[[/math]]

### theta

`[[math]]theta[[/math]]`: [[math]]theta[[/math]]

### Theta

`[[math]]Theta[[/math]]`: [[math]]Theta[[/math]]

### iota

`[[math]]iota[[/math]]`: [[math]]iota[[/math]]

### kappa

`[[math]]kappa[[/math]]`: [[math]]kappa[[/math]]

### lambda

`[[math]]lambda[[/math]]`: [[math]]lambda[[/math]]

### Lambda

`[[math]]Lambda[[/math]]`: [[math]]Lambda[[/math]]

### mu

`[[math]]mu[[/math]]`: [[math]]mu[[/math]]

### nu

`[[math]]nu[[/math]]`: [[math]]nu[[/math]]

### xi

`[[math]]xi[[/math]]`: [[math]]xi[[/math]]

### Xi

`[[math]]Xi[[/math]]`: [[math]]Xi[[/math]]

### pi

`[[math]]pi[[/math]]`: [[math]]pi[[/math]]

### Pi

`[[math]]Pi[[/math]]`: [[math]]Pi[[/math]]

### rho

`[[math]]rho[[/math]]`: [[math]]rho[[/math]]

### sigma

`[[math]]sigma[[/math]]`: [[math]]sigma[[/math]]

### Sigma

`[[math]]Sigma[[/math]]`: [[math]]Sigma[[/math]]

### tau

`[[math]]tau[[/math]]`: [[math]]tau[[/math]]

### upsilon

`[[math]]upsilon[[/math]]`: [[math]]upsilon[[/math]]

### Upsilon

`[[math]]Upsilon[[/math]]`: [[math]]Upsilon[[/math]]

### phi

`[[math]]phi[[/math]]`: [[math]]phi[[/math]]

### Phi

`[[math]]Phi[[/math]]`: [[math]]Phi[[/math]]

### chi

`[[math]]chi[[/math]]`: [[math]]chi[[/math]]

### psi

`[[math]]psi[[/math]]`: [[math]]psi[[/math]]

### Psi

`[[math]]Psi[[/math]]`: [[math]]Psi[[/math]]

### omega

`[[math]]omega[[/math]]`: [[math]]omega[[/math]]

### Omega

`[[math]]Omega[[/math]]`: [[math]]Omega[[/math]]

### partial

`[[math]]partial[[/math]]`: [[math]]partial[[/math]]

### nabla

`[[math]]nabla[[/math]]`: [[math]]nabla[[/math]]

### infty

`[[math]]infty[[/math]]`: [[math]]infty[[/math]]

### cos

`[[math]]cos[[/math]]`: [[math]]cos[[/math]]

### sin

`[[math]]sin[[/math]]`: [[math]]sin[[/math]]

### tan

`[[math]]tan[[/math]]`: [[math]]tan[[/math]]

### cosh

`[[math]]cosh[[/math]]`: [[math]]cosh[[/math]]

### sinh

`[[math]]sinh[[/math]]`: [[math]]sinh[[/math]]

### tanh

`[[math]]tanh[[/math]]`: [[math]]tanh[[/math]]



## Functions with 1 argument

### sub

`[[math]]1 sub{1}[[/math]]`: [[math]]1 sub{1}[[/math]]

### sup

`[[math]]1 sup{1}[[/math]]`: [[math]]1 sup{1}[[/math]]

### hat

`[[math]]hat{1}[[/math]]`: [[math]]hat{1}[[/math]]

### bar

`[[math]]bar{1}[[/math]]`: [[math]]bar{1}[[/math]]

### dot

`[[math]]dot{1}[[/math]]`: [[math]]dot{1}[[/math]]

### tilde

`[[math]]tilde{1}[[/math]]`: [[math]]tilde{1}[[/math]]

### vec

`[[math]]vec{1}[[/math]]`: [[math]]vec{1}[[/math]]

### check

`[[math]]check{1}[[/math]]`: [[math]]check{1}[[/math]]

### overleftarrow

`[[math]]overleftarrow{1}[[/math]]`: [[math]]overleftarrow{1}[[/math]]

### overrightarrow

`[[math]]overrightarrow{1}[[/math]]`: [[math]]overrightarrow{1}[[/math]]

### underline

`[[math]]underline{1}[[/math]]`: [[math]]underline{1}[[/math]]

### text

`[[math]]text{1}[[/math]]`: [[math]]text{1}[[/math]]

### lim

`[[math]]lim{1}[[/math]]`: [[math]]lim{1}[[/math]]



## Functions with 2 arguments

### frac

`[[math]]frac{1}{2} 3[[/math]]`: [[math]]frac{1}{2} 3[[/math]]

### cfrac

`[[math]]cfrac{1}{2} 3[[/math]]`: [[math]]cfrac{1}{2} 3[[/math]]

### sqrt

`[[math]]sqrt{1}{2} 3[[/math]]`: [[math]]sqrt{1}{2} 3[[/math]]

### int

`[[math]]int{1}{2} 3[[/math]]`: [[math]]int{1}{2} 3[[/math]]

### oint

`[[math]]oint{1}{2} 3[[/math]]`: [[math]]oint{1}{2} 3[[/math]]

### iint

`[[math]]iint{1}{2} 3[[/math]]`: [[math]]iint{1}{2} 3[[/math]]

### iiint

`[[math]]iiint{1}{2} 3[[/math]]`: [[math]]iiint{1}{2} 3[[/math]]

### sum

`[[math]]sum{1}{2} 3[[/math]]`: [[math]]sum{1}{2} 3[[/math]]

### prod

`[[math]]prod{1}{2} 3[[/math]]`: [[math]]prod{1}{2} 3[[/math]]

==> hmd-0.4.10.crate: hmd-0.4.10/math.md <==

# Math Formula

[[toc]]

## Symbols

### lt

`[[math]]lt[[/math]]`: [[math]]lt[[/math]]

### gt

`[[math]]gt[[/math]]`: [[math]]gt[[/math]]

### leq

`[[math]]leq[[/math]]`: [[math]]leq[[/math]]

### geq

`[[math]]geq[[/math]]`: [[math]]geq[[/math]]

### ll

`[[math]]ll[[/math]]`: [[math]]ll[[/math]]

### gg

`[[math]]gg[[/math]]`: [[math]]gg[[/math]]

### equiv

`[[math]]equiv[[/math]]`: [[math]]equiv[[/math]]

### subset

`[[math]]subset[[/math]]`: [[math]]subset[[/math]]

### supset

`[[math]]supset[[/math]]`: [[math]]supset[[/math]]

### approx

`[[math]]approx[[/math]]`: [[math]]approx[[/math]]

### in

`[[math]]in[[/math]]`: [[math]]in[[/math]]

### ni

`[[math]]ni[[/math]]`: [[math]]ni[[/math]]

### subseteq

`[[math]]subseteq[[/math]]`: [[math]]subseteq[[/math]]

### supseteq

`[[math]]supseteq[[/math]]`: [[math]]supseteq[[/math]]

### cong

`[[math]]cong[[/math]]`: [[math]]cong[[/math]]

### simeq

`[[math]]simeq[[/math]]`: [[math]]simeq[[/math]]

### notin

`[[math]]notin[[/math]]`: [[math]]notin[[/math]]

### propto

`[[math]]propto[[/math]]`: [[math]]propto[[/math]]

### neq

`[[math]]neq[[/math]]`: [[math]]neq[[/math]]

### therefore

`[[math]]therefore[[/math]]`: [[math]]therefore[[/math]]

### because

`[[math]]because[[/math]]`: [[math]]because[[/math]]

### pm

`[[math]]pm[[/math]]`: [[math]]pm[[/math]]

### mp

`[[math]]mp[[/math]]`: [[math]]mp[[/math]]

### times

`[[math]]times[[/math]]`: [[math]]times[[/math]]

### div

`[[math]]div[[/math]]`: [[math]]div[[/math]]

### star

`[[math]]star[[/math]]`: [[math]]star[[/math]]

### cap

`[[math]]cap[[/math]]`: [[math]]cap[[/math]]

### cup

`[[math]]cup[[/math]]`: [[math]]cup[[/math]]

### vee

`[[math]]vee[[/math]]`: [[math]]vee[[/math]]

### wedge

`[[math]]wedge[[/math]]`: [[math]]wedge[[/math]]

### cdot

`[[math]]cdot[[/math]]`: [[math]]cdot[[/math]]

### diamond

`[[math]]diamond[[/math]]`: [[math]]diamond[[/math]]

### bullet

`[[math]]bullet[[/math]]`: [[math]]bullet[[/math]]

### oplus

`[[math]]oplus[[/math]]`: [[math]]oplus[[/math]]

### ominus

`[[math]]ominus[[/math]]`: [[math]]ominus[[/math]]

### otimes

`[[math]]otimes[[/math]]`: [[math]]otimes[[/math]]

### oslash

`[[math]]oslash[[/math]]`: [[math]]oslash[[/math]]

### odot

`[[math]]odot[[/math]]`: [[math]]odot[[/math]]

### circ

`[[math]]circ[[/math]]`: [[math]]circ[[/math]]

### exists

`[[math]]exists[[/math]]`: [[math]]exists[[/math]]

### nexists

`[[math]]nexists[[/math]]`: [[math]]nexists[[/math]]

### forall

`[[math]]forall[[/math]]`: [[math]]forall[[/math]]

### neg

`[[math]]neg[[/math]]`: [[math]]neg[[/math]]

### land

`[[math]]land[[/math]]`: [[math]]land[[/math]]

### lor

`[[math]]lor[[/math]]`: [[math]]lor[[/math]]

### rightarrow

`[[math]]rightarrow[[/math]]`: [[math]]rightarrow[[/math]]

### leftarrow

`[[math]]leftarrow[[/math]]`: [[math]]leftarrow[[/math]]

### iff

`[[math]]iff[[/math]]`: [[math]]iff[[/math]]

### top

`[[math]]top[[/math]]`: [[math]]top[[/math]]

### bot

`[[math]]bot[[/math]]`: [[math]]bot[[/math]]

### varnothing

`[[math]]varnothing[[/math]]`: [[math]]varnothing[[/math]]

### quad

`[[math]]quad[[/math]]`: [[math]]quad[[/math]]

### backslash

`[[math]]backslash[[/math]]`: [[math]]backslash[[/math]]

### leftcurlybrace

`[[math]]leftcurlybrace[[/math]]`: [[math]]leftcurlybrace[[/math]]

### rightcurlybrace

`[[math]]rightcurlybrace[[/math]]`: [[math]]rightcurlybrace[[/math]]

### alpha

`[[math]]alpha[[/math]]`: [[math]]alpha[[/math]]

### beta

`[[math]]beta[[/math]]`: [[math]]beta[[/math]]

### gamma

`[[math]]gamma[[/math]]`: [[math]]gamma[[/math]]

### Gamma

`[[math]]Gamma[[/math]]`: [[math]]Gamma[[/math]]

### delta

`[[math]]delta[[/math]]`: [[math]]delta[[/math]]

### Delta

`[[math]]Delta[[/math]]`: [[math]]Delta[[/math]]

### epsilon

`[[math]]epsilon[[/math]]`: [[math]]epsilon[[/math]]

### zeta

`[[math]]zeta[[/math]]`: [[math]]zeta[[/math]]

### eta

`[[math]]eta[[/math]]`: [[math]]eta[[/math]]

### theta

`[[math]]theta[[/math]]`: [[math]]theta[[/math]]

### Theta

`[[math]]Theta[[/math]]`: [[math]]Theta[[/math]]

### iota

`[[math]]iota[[/math]]`: [[math]]iota[[/math]]

### kappa

`[[math]]kappa[[/math]]`: [[math]]kappa[[/math]]

### lambda

`[[math]]lambda[[/math]]`: [[math]]lambda[[/math]]

### Lambda

`[[math]]Lambda[[/math]]`: [[math]]Lambda[[/math]]

### mu

`[[math]]mu[[/math]]`: [[math]]mu[[/math]]

### nu

`[[math]]nu[[/math]]`: [[math]]nu[[/math]]

### xi

`[[math]]xi[[/math]]`: [[math]]xi[[/math]]

### Xi

`[[math]]Xi[[/math]]`: [[math]]Xi[[/math]]

### pi

`[[math]]pi[[/math]]`: [[math]]pi[[/math]]

### Pi

`[[math]]Pi[[/math]]`: [[math]]Pi[[/math]]

### rho

`[[math]]rho[[/math]]`: [[math]]rho[[/math]]

### sigma

`[[math]]sigma[[/math]]`: [[math]]sigma[[/math]]

### Sigma

`[[math]]Sigma[[/math]]`: [[math]]Sigma[[/math]]

### tau

`[[math]]tau[[/math]]`: [[math]]tau[[/math]]

### upsilon

`[[math]]upsilon[[/math]]`: [[math]]upsilon[[/math]]

### Upsilon

`[[math]]Upsilon[[/math]]`: [[math]]Upsilon[[/math]]

### phi

`[[math]]phi[[/math]]`: [[math]]phi[[/math]]

### Phi

`[[math]]Phi[[/math]]`: [[math]]Phi[[/math]]

### chi

`[[math]]chi[[/math]]`: [[math]]chi[[/math]]

### psi

`[[math]]psi[[/math]]`: [[math]]psi[[/math]]

### Psi

`[[math]]Psi[[/math]]`: [[math]]Psi[[/math]]

### omega

`[[math]]omega[[/math]]`: [[math]]omega[[/math]]

### Omega

`[[math]]Omega[[/math]]`: [[math]]Omega[[/math]]

### partial

`[[math]]partial[[/math]]`: [[math]]partial[[/math]]

### nabla

`[[math]]nabla[[/math]]`: [[math]]nabla[[/math]]

### infty

`[[math]]infty[[/math]]`: [[math]]infty[[/math]]

### cos

`[[math]]cos[[/math]]`: [[math]]cos[[/math]]

### sin

`[[math]]sin[[/math]]`: [[math]]sin[[/math]]

### tan

`[[math]]tan[[/math]]`: [[math]]tan[[/math]]

### cosh

`[[math]]cosh[[/math]]`: [[math]]cosh[[/math]]

### sinh

`[[math]]sinh[[/math]]`: [[math]]sinh[[/math]]

### tanh

`[[math]]tanh[[/math]]`: [[math]]tanh[[/math]]

### angle

`[[math]]angle[[/math]]`: [[math]]angle[[/math]]

### leftrightarrow

`[[math]]leftrightarrow[[/math]]`: [[math]]leftrightarrow[[/math]]

### sqcap

`[[math]]sqcap[[/math]]`: [[math]]sqcap[[/math]]

### sqcup

`[[math]]sqcup[[/math]]`: [[math]]sqcup[[/math]]

### space

`[[math]]space[[/math]]`: [[math]]space[[/math]]



## Functions with 1 argument

### sub

`[[math]]1 sub{1}[[/math]]`: [[math]]1 sub{1}[[/math]]

### sup

`[[math]]1 sup{1}[[/math]]`: [[math]]1 sup{1}[[/math]]

### hat

`[[math]]hat{1}[[/math]]`: [[math]]hat{1}[[/math]]

### bar

`[[math]]bar{1}[[/math]]`: [[math]]bar{1}[[/math]]

### dot

`[[math]]dot{1}[[/math]]`: [[math]]dot{1}[[/math]]

### tilde

`[[math]]tilde{1}[[/math]]`: [[math]]tilde{1}[[/math]]

### vec

`[[math]]vec{1}[[/math]]`: [[math]]vec{1}[[/math]]

### check

`[[math]]check{1}[[/math]]`: [[math]]check{1}[[/math]]

### overleftarrow

`[[math]]overleftarrow{1}[[/math]]`: [[math]]overleftarrow{1}[[/math]]

### overrightarrow

`[[math]]overrightarrow{1}[[/math]]`: [[math]]overrightarrow{1}[[/math]]

### underline

`[[math]]underline{1}[[/math]]`: [[math]]underline{1}[[/math]]

### text

`[[math]]text{1}[[/math]]`: [[math]]text{1}[[/math]]

### lim

`[[math]]lim{1}[[/math]]`: [[math]]lim{1}[[/math]]



## Functions with 2 arguments

### frac

`[[math]]frac{1}{2} 3[[/math]]`: [[math]]frac{1}{2} 3[[/math]]

### cfrac

`[[math]]cfrac{1}{2} 3[[/math]]`: [[math]]cfrac{1}{2} 3[[/math]]

### sqrt

`[[math]]sqrt{1}{2} 3[[/math]]`: [[math]]sqrt{1}{2} 3[[/math]]

### int

`[[math]]int{1}{2} 3[[/math]]`: [[math]]int{1}{2} 3[[/math]]

### oint

`[[math]]oint{1}{2} 3[[/math]]`: [[math]]oint{1}{2} 3[[/math]]

### iint

`[[math]]iint{1}{2} 3[[/math]]`: [[math]]iint{1}{2} 3[[/math]]

### iiint

`[[math]]iiint{1}{2} 3[[/math]]`: [[math]]iiint{1}{2} 3[[/math]]

### sum

`[[math]]sum{1}{2} 3[[/math]]`: [[math]]sum{1}{2} 3[[/math]]

### prod

`[[math]]prod{1}{2} 3[[/math]]`: [[math]]prod{1}{2} 3[[/math]]
